/* This file skins sliders */

.ui-slider { width: 200px; height: 23px; position: relative; background-repeat: no-repeat; background-position: center center; }
.ui-slider-handle { position: absolute; z-index: 1; height: 23px; width: 12px; top: 0px; left: 0px; background-image: url(i/slider-handle.gif);  }
.ui-slider-handle-active { border: 1px dotted black;  }
.ui-slider-disabled .ui-slider-handle { opacity: 0.5; filter: alpha(opacity=50); }
.ui-slider-range { position: absolute; background: #50A029; opacity: 0.3; filter: alpha(opacity=30); width: 100%; height: 100%; }

/* Default slider backgrounds */
.ui-slider, .ui-slider-1 { background-image: url(i/slider-bg-1.png); }
.ui-slider-2 { background-image: url(i/slider-bg-2.png); }
