
body {
  margin: 0;
  padding: 0;
}

.dialog {
  overflow: auto;
}

/*
#stacktrace, #repl {
  border: 1px solid black;
  float: left;
  margin: 1em;
  padding: 0.5em;
  background-color: #eee;
}

li {
  margin-left: 1em;
}

#repl input[type=text] {
  width: 50%;
}
*/

