/*
 * jQuery UI screen structure and presentation
 * This CSS file was generated by ThemeRoller, a Filament Group Project for jQuery UI
 * Author: Scott Jehl, scott@filamentgroup.com, http://www.filamentgroup.com
 * Visit themeroller.com
*/




/*UI accordion*/
.ui-accordion {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	font-family: Verdana, Arial, sans-serif;
	border-bottom: 1px solid #d3d3d3;
}
.ui-accordion-group {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	border: 1px solid #d3d3d3;
	border-bottom: none;
}
.ui-accordion-header {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	cursor: pointer;
	background: #e6e6e6 url(images/e6e6e6_40x100_textures_02_glass_75.png) 0 50% repeat-x;
}
.ui-accordion-header a {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	display: block;
	font-size: 1.1em;
	font-weight: normal;
	text-decoration: none;
	padding: .5em .5em .5em 1.7em;
	color: #555555;
	background: url(images/888888_7x7_arrow_right.gif) .5em 50% no-repeat;
}
.ui-accordion-header a:hover {
	background: url(images/454545_7x7_arrow_right.gif) .5em 50% no-repeat;
	color: #212121;
}
.ui-accordion-header:hover {
	background: #dadada url(images/dadada_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	color: #212121;
}
.selected .ui-accordion-header, .selected .ui-accordion-header:hover {
	background: #ffffff url(images/ffffff_40x100_textures_02_glass_65.png) 0 50% repeat-x;
}
.selected .ui-accordion-header a, .selected .ui-accordion-header a:hover {
	color: #222222;
	background: url(images/222222_7x7_arrow_down.gif) .5em 50% no-repeat;
}
.ui-accordion-content {
	padding: 1.5em 1.7em;	
	background: #ffffff;
	color: #222222;
	font-size: 1.1em;
}


/*slider*/
.ui-slider {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	font-family: Verdana, Arial, sans-serif;
	background: #ffffff;
	border: 1px solid #d3d3d3;
	height: .8em;
	position: relative;
}
.ui-slider-handle {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	position: absolute;
	z-index: 2;
	top: -3px;
	width: 1.2em;
	height: 1.2em;
	background: #ffffff url(images/ffffff_40x100_textures_02_glass_65.png) 0 50% repeat-x;
	border: 1px solid #dddddd;
}
.ui-slider-handle:hover {
	background: #dadada url(images/dadada_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	border: 1px solid #999999;
}
.ui-slider-handle-active, .ui-slider-handle-active:hover {
	background: #dadada url(images/dadada_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	border: 1px solid #dddddd;
}
.ui-slider-range {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	height: .8em;
	background: #dadada url(images/dadada_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	position: absolute;
	border: 1px solid #d3d3d3;
	border-left: 0;
	border-right: 0;
	top: -1px;
	z-index: 1;
}






/*dialog*/
.ui-dialog {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	font-family: Verdana, Arial, sans-serif;
	background: #ffffff;
	color: #222222;
	border: 4px solid #d3d3d3;
	position: relative;
}
.ui-dialog-content {
	border: 1px solid #d3d3d3;
	background: #ffffff;
	color: #222222;
}
.ui-resizable-handle {
	position: absolute;
	font-size: 0.1px;
	z-index: 99999;
}
.ui-resizable .ui-resizable-handle {
	display: block; 
}
body .ui-resizable-disabled .ui-resizable-handle { display: none; } /* use 'body' to make it more specific (css order) */
body .ui-resizable-autohide .ui-resizable-handle { display: none; } /* use 'body' to make it more specific (css order) */
.ui-resizable-n { 
	cursor: n-resize; 
	height: 7px; 
	width: 100%; 
	top: -5px; 
	left: 0px;  
}
.ui-resizable-s { 
	cursor: s-resize; 
	height: 7px; 
	width: 100%; 
	bottom: -5px; 
	left: 0px; 
}
.ui-resizable-e { 
	cursor: e-resize; 
	width: 7px; 
	right: -5px; 
	top: 0px; 
	height: 100%; 
}
.ui-resizable-w { 
	cursor: w-resize; 
	width: 7px; 
	left: -5px; 
	top: 0px; 
	height: 100%;
}
.ui-resizable-se { 
	cursor: se-resize; 
	width: 13px; 
	height: 13px; 
	right: 0px; 
	bottom: 0px; 
	background: url(images/222222_11x11_icon_resize_se.gif) no-repeat 0 0;
}
.ui-resizable-sw { 
	cursor: sw-resize; 
	width: 9px; 
	height: 9px; 
	left: 0px; 
	bottom: 0px;  
}
.ui-resizable-nw { 
	cursor: nw-resize; 
	width: 9px; 
	height: 9px; 
	left: 0px; 
	top: 0px; 
}
.ui-resizable-ne { 
	cursor: ne-resize; 
	width: 9px; 
	height: 9px; 
	right: 0px; 
	top: 0px; 
}
.ui-dialog-titlebar {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	padding: .5em 1.5em .5em 1em;
	color: #555555;
	background: #e6e6e6 url(images/e6e6e6_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	border-bottom: 1px solid #d3d3d3;
	font-size: 1.1em;
	font-weight: normal;
	position: relative;
}
.ui-dialog-title {

}
.ui-dialog-titlebar-close {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	background: url(images/888888_11x11_icon_close.gif) 0 0 no-repeat;
	position: absolute;
	right: 8px;
	top: .7em;
	width: 11px;
	height: 11px;
	z-index: 100;
}
.ui-dialog-titlebar-close-hover, .ui-dialog-titlebar-close:hover {
	background: url(images/454545_11x11_icon_close.gif) 0 0 no-repeat;
}
.ui-dialog-titlebar-close:active {
	background: url(images/222222_11x11_icon_close.gif) 0 0 no-repeat;
}
.ui-dialog-titlebar-close span {
	display: none;
}
.ui-dialog-content {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	background: #ffffff;
	color: #222222;
	padding: 1.5em 1.7em;	
}
.ui-dialog-buttonpane {
	position: absolute;
	bottom: 0;
	width: 100%;
	text-align: left;
	border-top: 1px solid #d3d3d3;
	background: ;
}
.ui-dialog-buttonpane button {
	margin: .5em 0 .5em 8px;
	color: #555555;
	background: #e6e6e6 url(images/e6e6e6_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	font-size: 1.1em;
	border: 1px solid #d3d3d3;
	cursor: pointer;
	padding: .2em .6em .3em .6em;
	line-height: 1.4em;
}
.ui-dialog-buttonpane button:hover {
	color: #212121;
	background: #dadada url(images/dadada_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	border: 1px solid #999999;
}
.ui-dialog-buttonpane button:active {
	color: #222222;
	background: #ffffff url(images/ffffff_40x100_textures_02_glass_65.png) 0 50% repeat-x;
	border: 1px solid #dddddd;
}
/* This file skins dialog */
.ui-dialog.ui-draggable .ui-dialog-titlebar,
.ui-dialog.ui-draggable .ui-dialog-titlebar {
	cursor: move;
}







/*datepicker*/
/* Main Style Sheet for jQuery UI date picker */
.ui-datepicker-div, #ui-datepicker-div, .ui-datepicker-inline {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	font-family: Verdana, Arial, sans-serif;
	background: #ffffff;
	font-size: 1.1em;
	border: 4px solid #d3d3d3;
	width: 15.5em;
	padding: 2.5em .5em .5em .5em;
	position: relative;
}
#ui-datepicker-div, .ui-datepicker-div {
	z-index: 9999; /*must have*/
	display: none;
	background: #ffffff;
}
.ui-datepicker-inline {
	float: left;
	display: block;
}
.ui-datepicker-control {
	display: none;
}
.ui-datepicker-current {
	display: none;
}
.ui-datepicker-next, .ui-datepicker-prev {
	position: absolute;
	left: .5em;
	top: .5em;
	background: #e6e6e6 url(images/e6e6e6_40x100_textures_02_glass_75.png) 0 50% repeat-x;
}
.ui-datepicker-next {
	left: 14.6em;
}
.ui-datepicker-next:hover, .ui-datepicker-prev:hover {
	background: #dadada url(images/dadada_40x100_textures_02_glass_75.png) 0 50% repeat-x;
}
.ui-datepicker-next a, .ui-datepicker-prev a {
	text-indent: -999999px;
	width: 1.3em;
	height: 1.4em;
	display: block;
	font-size: 1em;
	background: url(images/888888_7x7_arrow_left.gif) 50% 50% no-repeat;
	border: 1px solid #d3d3d3;
	cursor: pointer;
}
.ui-datepicker-next a {
	background: url(images/888888_7x7_arrow_right.gif) 50% 50% no-repeat;
}
.ui-datepicker-prev a:hover {
	background: url(images/454545_7x7_arrow_left.gif) 50% 50% no-repeat;
}
.ui-datepicker-next a:hover {
	background: url(images/454545_7x7_arrow_right.gif) 50% 50% no-repeat;
}
.ui-datepicker-prev a:active {
	background: url(images/222222_7x7_arrow_left.gif) 50% 50% no-repeat;
}
.ui-datepicker-next a:active {
	background: url(images/222222_7x7_arrow_right.gif) 50% 50% no-repeat;
}
.ui-datepicker-header select {
	border: 1px solid #d3d3d3;
	color: #555555;
	background: #e6e6e6;
	font-size: 1em;
	line-height: 1.4em;
	position: absolute;
	top: .5em;
	margin: 0 !important;
	
}
.ui-datepicker-header select.ui-datepicker-new-month {
width: 7em;
left: 2.2em;
}
.ui-datepicker-header select.ui-datepicker-new-year {
width: 5em;
left: 9.4em;
}
table.ui-datepicker {
	width: 15.5em;
	text-align: right;
}
table.ui-datepicker td a {
	padding: .1em .3em .1em 0;
	display: block;
	color: #555555;
	background: #e6e6e6 url(images/e6e6e6_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	cursor: pointer;
	border: 1px solid #ffffff;
}
table.ui-datepicker td a:hover {
	border: 1px solid #999999;
	color: #212121;
	background: #dadada url(images/dadada_40x100_textures_02_glass_75.png) 0 50% repeat-x;
}
table.ui-datepicker td a:active {
	border: 1px solid #dddddd;
	color: #222222;
	background: #ffffff url(images/ffffff_40x100_textures_02_glass_65.png) 0 50% repeat-x;
}
table.ui-datepicker .ui-datepicker-title-row td {
	padding: .3em 0;
	text-align: center;
	font-size: .9em;
	color: #222222;
	text-transform: uppercase;
	/*border-bottom: 1px solid #d3d3d3;*/
}

table.ui-datepicker .ui-datepicker-title-row td a {
	color: #222222;
}






/*colorpicker*/
.ui-colorpicker {
	width: 356px;
	height: 176px;
	overflow: hidden;
	position: absolute;
	background: url(images/colorpicker_background.png);
	font-family: Arial, Helvetica, sans-serif;
	display: none;
}
.ui-colorpicker-color {
	width: 150px;
	height: 150px;
	left: 14px;
	top: 13px;
	position: absolute;
	background: #f00;
	overflow: hidden;
	cursor: crosshair;
}
.ui-colorpicker-color div {
	position: absolute;
	top: 0;
	left: 0;
	width: 150px;
	height: 150px;
	background: url(images/colorpicker_overlay.png);
}
.ui-colorpicker-color div div {
	position: absolute;
	top: 0;
	left: 0;
	width: 11px;
	height: 11px;
	overflow: hidden;
	background: url(images/colorpicker_select.gif);
	margin: -5px 0 0 -5px;
}
.ui-colorpicker-hue {
	position: absolute;
	top: 13px;
	left: 171px;
	width: 35px;
	height: 150px;
	cursor: n-resize;
}
.ui-colorpicker-hue div {
	position: absolute;
	width: 35px;
	height: 9px;
	overflow: hidden;
	background: url(images/colorpicker_indic.gif) left top;
	margin: -4px 0 0 0;
	left: 0px;
}
.ui-colorpicker-new-color {
	position: absolute;
	width: 60px;
	height: 30px;
	left: 213px;
	top: 13px;
	background: #f00;
}
.ui-colorpicker-current-color {
	position: absolute;
	width: 60px;
	height: 30px;
	left: 283px;
	top: 13px;
	background: #f00;
}
.colorpicker input {
	background-color: transparent;
	border: 1px solid transparent;
	position: absolute;
	font-size: 10px;
	font-family: Arial, Helvetica, sans-serif;
	color: #898989;
	top: 4px;
	right: 11px;
	text-align: right;
	margin: 0;
	padding: 0;
	height: 11px;
}
.ui-colorpicker-hex {
	position: absolute;
	width: 72px;
	height: 22px;
	background: url(images/colorpicker_hex.png) top;
	left: 212px;
	top: 142px;
}
.ui-colorpicker input {
	height: 15px;
}
.ui-colorpicker-hex input {
	margin-left: 18px;
	right: 6px;
	width: 47px;
}
.ui-colorpicker-field {
	height: 22px;
	width: 62px;
	background-position: top;
	position: absolute;
}
.ui-colorpicker-field label {
	padding-left: 17px;
	font-size: 10px;
}
.ui-colorpicker-field input {
	width: 25px;
}
.ui-colorpicker-field span {
	position: absolute;
	width: 12px;
	height: 22px;
	overflow: hidden;
	top: 0;
	right: 0;
	cursor: n-resize;
}
.ui-colorpicker-rgb-r {
	background-image: url(images/colorpicker_rgb_r.png);
	top: 52px;
	left: 212px;
}
.ui-colorpicker-rgb-g {
	background-image: url(images/colorpicker_rgb_g.png);
	top: 82px;
	left: 212px;
}
.ui-colorpicker-rgb-b {
	background-image: url(images/colorpicker_rgb_b.png);
	top: 112px;
	left: 212px;
}
.ui-colorpicker-hsb-h {
	background-image: url(images/colorpicker_hsb_h.png);
	top: 52px;
	left: 282px;
}
.ui-colorpicker-hsb-s {
	background-image: url(images/colorpicker_hsb_s.png);
	top: 82px;
	left: 282px;
}
.ui-colorpicker-hsb-b {
	background-image: url(images/colorpicker_hsb_b.png);
	top: 112px;
	left: 282px;
}
.ui-colorpicker-submit {
	position: absolute;
	left: 296px;
	top: 144px;
	overflow: hidden;
}
.ui-colorpicker-focus {
	background-position: center;
}
.ui-colorpicker-hex.ui-colorpicker-focus {
	background-position: bottom;
}
.ui-colorpicker-submit.ui-colorpicker-focus {
	background-position: bottom;
}
.ui-colorpicker-slider {
	background-position: bottom;
}


/*autocomplete*/
.ui-autocomplete-results {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	font-family: Verdana, Arial, sans-serif;
	font-size: 1.1em;

	border: 1px solid #d3d3d3;
	background: #ffffff;
	color: #222222;

	overflow: hidden;
	z-index: 99999;
}

.ui-autocomplete-results ul {
	width: 100%;
	list-style-position: outside;
	list-style: none;
	padding: 0;
	margin: 0;
}

.ui-autocomplete-results li {
	margin: 0px;
	padding: 2px 5px;
	cursor: default;
	display: block;
	/* 
	if width will be 100% horizontal scrollbar will apear 
	when scroll mode will be used
	*/
	/*width: 100%;*/
	font: menu;
	font-size: 12px;
	/* 
	it is very important, if line-height not setted or setted 
	in relative units scroll will be broken in firefox
	*/
	line-height: 16px;
	overflow: hidden;
	

	border: 1px solid #d3d3d3;
	background: #e6e6e6 url(images/e6e6e6_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	font-weight: normal;
	color: #555555 !important;	
	
}

.ui-autocomplete-loading {
	background: white url('indicator.gif') right center no-repeat;
}

.ui-autocomplete-results li.ui-autocomplete-over {
	border: 1px solid #999999;
	background: #dadada url(images/dadada_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	font-weight: normal;
	color: #212121 !important;
}





/* ProgressBar */

.ui-progressbar {
	width: 400px; height: 20px;
	border: 1px #ccc solid;
	background:#E0E8F3 url(images/bg.gif) repeat-x scroll 0%;
	position:relative;
}

.ui-progressbar-wrap {
	position: relative;
	height: auto;
	width: auto;
	line-height: 18px;
	_line-height: 16px;
}

.ui-progressbar-bar {
	background:#9CBFEE url(images/progress-bg.gif) repeat-x scroll left center;
	border-bottom:1px solid #7FA9E4;
	border-right:1px solid #7FA9E4;
	border-top:1px solid #D1E4FD;
	position: absolute;
}

.ui-progressbar-text {
	color:#fff;
	overflow: hidden;
	white-space: nowrap;
	font-size: 11px;
	font-weight: bold;
	padding-left: 5px;
}

.ui-progressbar-text-back {
	color:#000;
	padding-top: 1px;
	padding-bottom: 1px;
	padding-right: 1px;
}

.ui-progressbar-disabled {
	opacity:.5;
	filter:Alpha(Opacity=50);
}


/* custom */
.ui-progressbar-text.right-align {
	text-align: right;
	padding: 0 5px 0 0;
}
.ui-progressbar-inner-custom {
	background: url(images/custom-bar.gif) repeat-x scroll left center;
	border-bottom:1px solid #EFEFEF;
	border-right:0pt none;
	border-top:1px solid #BEBEBE;
	height:15px;
}
.bold {
	color: red !important;
}
.ui-hidden {
	left:-10000px;
	position:absolute;
	top:-10000px;
	visibility:hidden;
}



/*
Generic ThemeRoller Classes
>> Make your jQuery Components ThemeRoller-Compatible!
*/

/*component global class*/
.ui-component {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
	font-family: Verdana, Arial, sans-serif;
	font-size: 1.1em;
}
/*component content styles*/
.ui-component-content {
	border: 1px solid #d3d3d3;
	background: #ffffff;
	color: #222222;
}
.ui-component-content a {
	color: #222222;
	text-decoration: underline;
}
/*component states*/
.ui-default-state {
	border: 1px solid #d3d3d3;
	background: #e6e6e6 url(images/e6e6e6_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	font-weight: normal;
	color: #555555 !important;
}
.ui-default-state a {
	color: #555555;
}
.ui-default-state:hover, .ui-hover-state {
	border: 1px solid #999999;
	background: #dadada url(images/dadada_40x100_textures_02_glass_75.png) 0 50% repeat-x;
	font-weight: normal;
	color: #212121 !important;
}
.ui-hover-state a {
	color: #212121;
}
.ui-default-state:active, .ui-active-state {
	border: 1px solid #dddddd;
	background: #ffffff url(images/ffffff_40x100_textures_02_glass_65.png) 0 50% repeat-x;
	font-weight: normal;
	color: #222222 !important;
	outline: none;
}
.ui-active-state a {
	color: #222222;
	outline: none;
}
/*icons*/
.ui-arrow-right-default {background: url(images/888888_7x7_arrow_right.gif) no-repeat 50% 50%;}
.ui-arrow-right-default:hover, .ui-arrow-right-hover {background: url(images/454545_7x7_arrow_right.gif) no-repeat 50% 50%;}
.ui-arrow-right-default:active, .ui-arrow-right-active {background: url(images/222222_7x7_arrow_right.gif) no-repeat 50% 50%;}
.ui-arrow-left-default {background: url(images/888888_7x7_arrow_left.gif) no-repeat 50% 50%;}
.ui-arrow-left-default:hover, .ui-arrow-left-hover {background: url(images/454545_7x7_arrow_left.gif) no-repeat 50% 50%;}
.ui-arrow-left-default:active, .ui-arrow-left-active {background: url(images/222222_7x7_arrow_left.gif) no-repeat 50% 50%;}
.ui-arrow-down-default {background: url(images/888888_7x7_arrow_down.gif) no-repeat 50% 50%;}
.ui-arrow-down-default:hover, .ui-arrow-down-hover {background: url(images/454545_7x7_arrow_down.gif) no-repeat 50% 50%;}
.ui-arrow-down-default:active, .ui-arrow-down-active {background: url(images/222222_7x7_arrow_down.gif) no-repeat 50% 50%;}
.ui-arrow-up-default {background: url(images/888888_7x7_arrow_up.gif) no-repeat 50% 50%;}
.ui-arrow-up-default:hover, .ui-arrow-up-hover {background: url(images/454545_7x7_arrow_up.gif) no-repeat 50% 50%;}
.ui-arrow-up-default:active, .ui-arrow-up-active {background: url(images/222222_7x7_arrow_up.gif) no-repeat 50% 50%;}
.ui-close-default {background: url(images/888888_11x11_icon_close.gif) no-repeat 50% 50%;}
.ui-close-default:hover, .ui-close-hover {background: url(images/454545_11x11_icon_close.gif) no-repeat 50% 50%;}
.ui-close-default:active, .ui-close-active {background: url(images/222222_11x11_icon_close.gif) no-repeat 50% 50%;}
.ui-folder-closed-default {background: url(images/888888_11x11_icon_folder_closed.gif) no-repeat 50% 50%;}
.ui-folder-closed-default:hover, .ui-folder-closed-hover {background: url(images/454545_11x11_icon_folder_closed.gif) no-repeat 50% 50%;}
.ui-folder-closed-default:active, .ui-folder-closed-active {background: url(images/222222_11x11_icon_folder_closed.gif) no-repeat 50% 50%;}
.ui-folder-open-default {background: url(images/888888_11x11_icon_folder_open.gif) no-repeat 50% 50%;}
.ui-folder-open-default:hover, .ui-folder-open-hover {background: url(images/454545_11x11_icon_folder_open.gif) no-repeat 50% 50%;}
.ui-folder-open-default:active, .ui-folder-open-active {background: url(images/222222_11x11_icon_folder_open.gif) no-repeat 50% 50%;}
.ui-doc-default {background: url(images/888888_11x11_icon_doc.gif) no-repeat 50% 50%;}
.ui-doc-default:hover, .ui-doc-hover {background: url(images/454545_11x11_icon_doc.gif) no-repeat 50% 50%;}
.ui-doc-default:active, .ui-doc-active {background: url(images/222222_11x11_icon_doc.gif) no-repeat 50% 50%;}
.ui-arrows-leftright-default {background: url(images/888888_11x11_icon_arrows_leftright.gif) no-repeat 50% 50%;}
.ui-arrows-leftright-default:hover, .ui-arrows-leftright-hover {background: url(images/454545_11x11_icon_arrows_leftright.gif) no-repeat 50% 50%;}
.ui-arrows-leftright-default:active, .ui-arrows-leftright-active {background: url(images/222222_11x11_icon_arrows_leftright.gif) no-repeat 50% 50%;}
.ui-arrows-updown-default {background: url(images/888888_11x11_icon_arrows_updown.gif) no-repeat 50% 50%;}
.ui-arrows-updown-default:hover, .ui-arrows-updown-hover {background: url(images/454545_11x11_icon_arrows_updown.gif) no-repeat 50% 50%;}
.ui-arrows-updown-default:active, .ui-arrows-updown-active {background: url(images/222222_11x11_icon_arrows_updown.gif) no-repeat 50% 50%;}
.ui-minus-default {background: url(images/888888_11x11_icon_minus.gif) no-repeat 50% 50%;}
.ui-minus-default:hover, .ui-minus-hover {background: url(images/454545_11x11_icon_minus.gif) no-repeat 50% 50%;}
.ui-minus-default:active, .ui-minus-active {background: url(images/222222_11x11_icon_minus.gif) no-repeat 50% 50%;}
.ui-plus-default {background: url(images/888888_11x11_icon_plus.gif) no-repeat 50% 50%;}
.ui-plus-default:hover, .ui-plus-hover {background: url(images/454545_11x11_icon_plus.gif) no-repeat 50% 50%;}
.ui-plus-default:active, .ui-plus-active {background: url(images/222222_11x11_icon_plus.gif) no-repeat 50% 50%;}
/*hidden elements*/
.ui-hidden {
	display: none;/* for accessible hiding: position: absolute; left: -99999999px*/;
}
.ui-accessible-hidden {
	 position: absolute; left: -99999999px;
}
/*reset styles*/
.ui-reset {
	/*resets*/margin: 0; padding: 0; border: 0; outline: 0; line-height: 1.3; text-decoration: none; font-size: 100%; list-style: none;
}
/*clearfix class*/
.ui-clearfix:after {
    content: "."; 
    display: block; 
    height: 0; 
    clear: both; 
    visibility: hidden;
}
.ui-clearfix {display: inline-block;}
/* Hides from IE-mac \*/
* html .ui-clearfix {height: 1%;}
.ui-clearfix {display: block;}
/* End hide from IE-mac */

/* Note: for resizable styles, use the styles listed above in the dialog section */




/* UI Spinner */
.ui-spinner {
	width: 15em;
	display: block;
	position: relative;
	overflow: hidden;
	border: 1px solid #999;
	background: #FEFEFE url(./images/spinner-bg.gif) repeat-x left bottom;
	padding: 0 5px;
}

.ui-spinner-disabled {
	background: #F4F4F4;
	color: #CCC;
}

.ui-spinner-box {
	width: 90%;
	height: 100%;
	float: left;
	font-size: 125%;
	border: none;
	background: none;
	padding: 0;
}

.ui-spinner-up,
.ui-spinner-down {
	width: 10%;
	height: 50%;
	font-size: 0.5em;
	padding: 0;
	margin: 0;
	z-index: 100;
	text-align: center;
	vertical-align: middle;
	position: absolute;
	right: 0;
	cursor: default;
	border: 1px solid #999;
	border-right: none;
	border-top: none;
}

.ui-spinner-down {
	bottom: 0;
	border-bottom: 0;
}

.ui-spinner-pressed {
	background: #FEFEFE;
}

.ui-spinner-list,
.ui-spinner-listitem {
	margin: 0;
	padding: 0;
}